@@ -1,5 +1,5 @@
 from django.db import models
-from django.utils.safestring import mark_safe
+from django.utils.html import format_html
 from django_crypto_fields.fields import EncryptedCharField, EncryptedTextField
 from edc_constants.choices import YES_NO
 from edc_model.validators import cell_number, telephone_number
@@ -10,7 +10,7 @@ class SubjectWorkFieldsMixin(models.Model):
     may_call_work = models.CharField(
         max_length=25,
         choices=YES_NO,
-        verbose_name=mark_safe(
+        verbose_name=format_html(
             "Has the participant given permission to contacted <b>at work</b> by telephone "
             "or cell by study staff for follow-up purposes during the study?"
         ),
